==> haskell-djinn-lib-0.0.1.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.3
visibility:           public
id:                   djinn-lib-0.0.1.3-Kh0jdm98RdCFuCTOtoePfw
key:                  djinn-lib-0.0.1.3-Kh0jdm98RdCFuCTOtoePfw
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  ea99891173ffcdaa005870a1ec4ec41d
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-8.10.1/site-local/djinn-lib-0.0.1.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/djinn-lib-0.0.1.3
hs-libraries:         HSdjinn-lib-0.0.1.3-Kh0jdm98RdCFuCTOtoePfw
depends:
    base-4.14.0.0 containers-0.6.2.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-lib-0.0.1.3-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.3
visibility:           public
id:                   djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm
key:                  djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  d177878757e6ff6a104ccbb0665b73d4
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-8.10.2/site-local/djinn-lib-0.0.1.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/djinn-lib-0.0.1.3
hs-libraries:         HSdjinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm
depends:
    base-4.14.1.0 containers-0.6.2.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
